==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/pt_BR.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartilhamento federado",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Deseja adicionar o compartilhamento remoto {name} de {owner}@{remote}?",
    "Remote share" : "Compartilhamento remoto",
    "Remote share password" : "Senha do compartilhamento remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar compartilhamento remoto",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "ID de Nuvem Federada Inválida",
    "Server to server sharing is not enabled on this server" : "Servidor para compartilhamento de servidor não está ativo neste servidor",
    "Couldn't establish a federated share." : "Não foi possível estabelecer um compartilhamento federado.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Não foi possível estabelecer um compartilhamento federado, talvez a senha esteja incorreta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitação de Compartilhamento Federado enviada, você receberá um convite. Verifique suas notificações.",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém caracteres inválidos.",
    "Not allowed to create a federated share with the owner." : "Não é permitido criar um compartilhamento federado com o proprietário.",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticar-se ao compartilhamento remoto. A senha pode estar incorreta",
    "Storage not valid" : "Armazenamento inválido",
    "Federated share added" : "Compartilhamento Federado adicionado",
    "Couldn't add remote share" : "Não foi possível adicionar o compartilhamento remoto",
    "Sharing %s failed, because this item is already shared with %s" : "Compartilhamento %s falhou porque este item já está compartilhado com %s",
    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento federado com o mesmo usuário",
    "File is already shared with %s" : "O arquivo já é compartilhado com %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartilhamento %s falhou, não foi possível encontrar %s. Talvez o servidor esteja inacessível ou esteja sendo utilizado um certificado de auto-assinatura",
    "Could not find share" : "Não foi possível encontrar o compartilhamento",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Você recebeu \"%3$s\" como um compartilhamento remoto de %1$s ( em nome de %2$s )",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Você recebeu {share} como um compartilhamento remoto do {user} (em nome de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Você recebeu \"%3$s\" como um compartilhamento remoto de %1$s",
    "You received {share} as a remote share from {user}" : "Você recebeu {share} como um compartilhamento remoto de {user}",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartilhe comigo através do meu ID de Nuvem Federada #Nextcloud, veja %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartilhe comigo através do meu ID de Nuvem Federada #Nextcloud",
    "Sharing" : "Compartilhar",
    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Federada",
    "Open documentation" : "Abrir documentação",
    "Adjust how people can share between servers." : "Ajustar como as pessoas podem compartilhar entre servidores.",
    "Allow users on this server to send shares to other servers" : "Permitir que os usuários deste servidor enviem compartilhamentos para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir que os usuários deste servidor recebam compartilhamentos de outros servidores",
    "Search global and public address book for users" : "Procurar por usuários em catálogo de endereços global e público",
    "Allow users to publish their data to a global and public address book" : "Permitir que os usuários publiquem seus dados em um catálogo de endereços global e público",
    "Federated Cloud" : "Nuvem Federada",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Você pode compartilhar com qualquer um que use Nextcloud, ownCloud ou Pydio! Apenas coloque a ID de Nuvem Federada no diálogo de compartilhamento. Isto é algo como person@cloud.example.com",
    "Your Federated Cloud ID:" : "Sua ID de Nuvem Federada:",
    "Share it so your friends can share files with you:" : "Compartilhe e seus amigos poderão compartilhar arquivos com você:",
    "Add to your website" : "Adicione ao seu website",
    "Share with me via Nextcloud" : "Compartilhe comigo via Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Search global and public address book for users and let local users publish their data" : "Pesquise o catálogo de endereços global e público para usuários e deixe os usuários locais publicarem seus dados"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/pt_BR.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartilhamento federado",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Deseja adicionar o compartilhamento remoto {name} de {owner}@{remote}?",
    "Remote share" : "Compartilhamento remoto",
    "Remote share password" : "Senha do compartilhamento remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar compartilhamento remoto",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "ID de Nuvem Federada Inválida",
    "Server to server sharing is not enabled on this server" : "Servidor para compartilhamento de servidor não está ativo neste servidor",
    "Couldn't establish a federated share." : "Não foi possível estabelecer um compartilhamento federado.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Não foi possível estabelecer um compartilhamento federado, talvez a senha esteja incorreta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitação de Compartilhamento Federado enviada, você receberá um convite. Verifique suas notificações.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Não foi possível estabelecer um compartilhamento federado, parece que o servidor a se federar é muito antigo (Nextcloud <= 9).",
    "Sharing %s failed, because this item is already shared with %s" : "Compartilhamento %s falhou porque este item já está compartilhado com %s",
    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento federado com o mesmo usuário",
    "File is already shared with %s" : "O arquivo já é compartilhado com %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartilhamento %s falhou, não foi possível encontrar %s. Talvez o servidor esteja inacessível ou esteja sendo utilizado um certificado de auto-assinatura",
    "Could not find share" : "Não foi possível encontrar o compartilhamento",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Você recebeu \"%3$s\" como um compartilhamento remoto de %1$s ( em nome de %2$s )",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Você recebeu {share} como um compartilhamento remoto do {user} (em nome de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Você recebeu \"%3$s\" como um compartilhamento remoto de %1$s",
    "You received {share} as a remote share from {user}" : "Você recebeu {share} como um compartilhamento remoto de {user}",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartilhe comigo através do meu ID de Nuvem Federada #Nextcloud, veja %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartilhe comigo através do meu ID de Nuvem Federada #Nextcloud",
    "Sharing" : "Compartilhar",
    "Federated file sharing" : "Compartilhamento federado de arquivos",
    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Federada",
    "Open documentation" : "Abrir documentação",
    "Adjust how people can share between servers." : "Ajustar como as pessoas podem compartilhar entre servidores.",
    "Allow users on this server to send shares to other servers" : "Permitir que os usuários deste servidor enviem compartilhamentos para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir que os usuários deste servidor recebam compartilhamentos de outros servidores",
    "Search global and public address book for users" : "Procurar por usuários em catálogo de endereços global e público",
    "Allow users to publish their data to a global and public address book" : "Permitir que os usuários publiquem seus dados em um catálogo de endereços global e público",
    "Federated Cloud" : "Nuvem Federada",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Você pode compartilhar com qualquer um que use Nextcloud, ownCloud ou Pydio! Apenas coloque a ID de Nuvem Federada no diálogo de compartilhamento. Isto é algo como person@cloud.example.com",
    "Your Federated Cloud ID:" : "Sua ID de Nuvem Federada:",
    "Share it so your friends can share files with you:" : "Compartilhe e seus amigos poderão compartilhar arquivos com você:",
    "Add to your website" : "Adicione ao seu website",
    "Share with me via Nextcloud" : "Compartilhe comigo via Nextcloud",
    "HTML Code:" : "Código HTML:",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém caracteres inválidos.",
    "Not allowed to create a federated share with the owner." : "Não é permitido criar um compartilhamento federado com o proprietário.",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticar-se ao compartilhamento remoto. A senha pode estar incorreta",
    "Storage not valid" : "Armazenamento inválido",
    "Federated share added" : "Compartilhamento Federado adicionado",
    "Couldn't add remote share" : "Não foi possível adicionar o compartilhamento remoto",
    "Search global and public address book for users and let local users publish their data" : "Pesquise o catálogo de endereços global e público para usuários e deixe os usuários locais publicarem seus dados"
},
"nplurals=2; plural=(n > 1);");
